# File Check

The File Check plugin tries to detect common issues in uploaded files that are known to cause
issues while printing and which in the past have caused support requests on OctoPrint's Community
Forums, as well as leaked sensitive data such as API keys.

![Screenshot](https://raw.githubusercontent.com/OctoPrint/OctoPrint-FileCheck/master/extras/screenshot.png)

It currently detects and warns about the following issues:

  * Outdated placeholder `{travel_speed}` left in the GCODE generated by the slicer. See
    [here](https://faq.octoprint.org/file-check-travel-speed) for details on this.
  * API keys leaked by the slicer into the GCODE. See
    [here](https://faq.octoprint.org/file-check-leaked-api-key) for details on this.

Since version 2024.3.27 it also supports checking selected files as well as all uploaded files for issues on
the press of a button (if `grep` is available), not just freshly uploaded files.

## Setup

The plugin is part of the core dependencies of OctoPrint 1.4.1+ and will be installed automatically alongside it.

In case you want to manually install it for whatever reason, install via the bundled
[Plugin Manager](https://docs.octoprint.org/en/master/bundledplugins/pluginmanager.html)
or manually using this URL:

    https://github.com/OctoPrint/OctoPrint-FileCheck/archive/master.zip
